@@ -2,10 +2,10 @@
  * 
  * codeconv.c -
  * 
- * $Id: codeconv.c,v 1.29.8.8 2008-03-06 15:38:08 opengl2772 Exp $
+ * $Id: codeconv.c,v 1.29.8.5 2005/09/02 09:23:45 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2008 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2005 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,9 @@
  * (Quick KANJI code Converter  C Version 1.0) 
  */
 
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -39,19 +42,10 @@
 #  include "support.h"
 #endif
 
-#include <stdio.h>
-#ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "libnamazu.h"
@@ -255,7 +249,7 @@ euctosjis(uchar *s)
 		break;
 	    }
 	    if (nmz_iseuc(c2)) {
-		c = jistojms((uchar)(c & 0x7f), (uchar)(c2 & 0x7f));
+		c = jistojms(c & 0x7f, c2 & 0x7f);
 		*(s + i++) = c;
 		*(s + i++) = kanji2nd;
 	    } else {
