@@ -2,7 +2,7 @@
  * 
  * idxname.c - Idx handling routines.
  *
- * $Id: idxname.c,v 1.25.8.5 2004/03/20 15:25:10 usu Exp $
+ * $Id: idxname.c,v 1.25.8.6 2005/07/21 08:47:54 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000,2001,2003 Namazu Project All rights reserved.
@@ -153,7 +153,8 @@ nmz_complete_idxnames(void)
     int i;
 
     for (i = 0; i < indices.num; i++) {
- 	if (*indices.names[i] == '+' && isalnum(*(indices.names[i] + 1))) {
+ 	if (*indices.names[i] == '+' && 
+	    isalnum((unsigned char)*(indices.names[i] + 1))) {
 	    char *tmp;
 	    tmp = malloc(strlen(defaultidx) 
 				  + 1 + strlen(indices.names[i]) + 1);
