@@ -3,7 +3,7 @@
 # nmzidx.pl - subroutines for accessing Namazu index files (NMZ.*)
 #         by furukawa@tcp-ip.or.jp
 #
-# $Id: nmzidx.pl,v 1.13.4.4 2004/01/30 18:28:19 opengl2772 Exp $
+# $Id: nmzidx.pl,v 1.13.4.6 2004/11/01 12:56:44 opengl2772 Exp $
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #
 
 use strict;
+use English;
 use IO::File;
 use DirHandle;
 
@@ -141,7 +142,7 @@ sub getlist{
 sub putline{
     my $self = shift;
     if (@_){
-	my $output;
+        my $output;
 
         $output = shift;
         $output =~ s/\n.*$//s;
@@ -225,14 +226,16 @@ sub new{
     $self->{'field'} = new nmzfield;
     $self->{'field'}->open_all($par);
     $self->{'offset'} = 0;
-    $self->{'size'} = (-s $self->{'t'}) / length(pack('N', 0));
-    $self->{'valid'} = $self->{'size'};
+    if (defined $self->{'t'}) {
+        $self->{'size'} = (-s $self->{'t'}) / length(pack('N', 0));
+        $self->{'valid'} = $self->{'size'};
+    }
     return $self;
 }
 
 sub close{
     my $self = shift;
-    $self->{'t'}->close;
+    $self->{'t'}->close if defined $self->{'t'};
     $self->{'r'}->close if defined $self->{'r'};
     $self->{'field'}->close;
 }
@@ -643,10 +646,12 @@ sub write_status{
     my $in = shift;
 
     my $key = undef;
-    $key = comma($self->{'word'}->{'size'}) if defined $self->{'word'};
+    $key = $self->{'word'}->{'size'} if defined $self->{'word'};
+    my $key_comma = comma($key);
 
     my $file = undef;
-    $file = comma($self->{'flist'}->{'valid'}) if defined $self->{'flist'};
+    $file = $self->{'flist'}->{'valid'} if defined $self->{'flist'};
+    my $file_comma = comma($file);
 
     if ($self->{'mode'} =~ /w/i){
         my $fi = &nmzlib::open_db($in, 'status');
@@ -666,8 +671,8 @@ sub write_status{
                 $fo = &nmzlib::open_db($self, $1);
 
                 while (defined(my $line = $fi->getline)){
-                    $line =~ s/(\<\!-- FILE --\>).*?\1/$1 $file $1/ if defined $file;
-                    $line =~ s/(\<\!-- KEY --\>).*?\1/$1 $key $1/ if defined $key;
+                    $line =~ s/(\<\!-- FILE --\>).*?\1/$1 $file_comma $1/ if defined $file_comma;
+                    $line =~ s/(\<\!-- KEY --\>).*?\1/$1 $key_comma $1/ if defined $key_comma;
                     $fo->print($line);
                 }
                 $fi->close;
@@ -687,7 +692,7 @@ sub log_open{
     if (defined $fh){
         binmode $fh;
         $fh->print("$tag\n") if defined $tag;
-        $self->log_putline("Date:",  localtime($^T) . "");
+        $self->log_putline("Date:",  localtime($English::BASETIME) . "");
     }
     return $self->{'log'};
 }
@@ -700,14 +705,15 @@ sub log_putline{
 sub log_close{
     my $self = shift;
     if (defined $self->{'log'}){
-        $self->log_putline("Perl:", $]);
-        $self->log_putline("System:", $^O);
-        $self->log_putline("Time (sec):", (time - $^T));
+        $self->log_putline("Perl:", sprintf("%f", $English::PERL_VERSION));
+        $self->log_putline("System:", $English::OSNAME);
+        $self->log_putline("Time (sec):", (time - $English::BASETIME));
         $self->{'log'}->print("\n");
         $self->{'log'}->close;
     }
 }
 
+
 # copy from util.pl
 sub comma ($) {
     my ($num) = @_;
