@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: time.pl,v 1.5.2.4 2006/11/10 16:46:20 opengl2772 Exp $
+# $Id: time.pl,v 1.5.2.2 2006/01/20 20:44:43 opengl2772 Exp $
 # Copyright (C) 2004-2006 Tadamasa Teranishi
 #               2004-2006 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -241,12 +241,8 @@ sub rfc822time_to_mtime ($) {
 
         $year += 2000 if ($year < 50);
         $year += 1900 if (50 <= $year && $year <= 99);
-        return -1 if ($year >= 2038);
 
-        my $mtime;
-        eval {
-            $mtime = timegm($sec, $min, $hour, $mday, $month, $year);
-        } || return -1;
+	my $mtime = timegm($sec, $min, $hour, $mday, $month, $year);
 
         my $offset;
         if ($timezone =~ /([+-])(\d{2})([0-5][0-9])/) {
