@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: util.pl,v 1.22.4.12 2006/01/24 12:42:55 opengl2772 Exp $
+# $Id: util.pl,v 1.22.4.13 2006/02/05 18:53:30 opengl2772 Exp $
 # Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
 # Copyright (C) 2000-2006 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -557,4 +557,22 @@ sub win32_yen_to_slash ($) {
     }
 }
 
+# Substitution of "-r" that doesn't correspond to ACL of NTFS
+sub canopen($)
+{
+    my ($file) = @_;
+
+    my $fh;
+
+    return (-r $file) if ($English::OSNAME ne "MSWin32");
+
+    $fh = new IO::File $file, "r";
+
+    return 0 if (!defined $fh);
+
+    $fh->close();
+
+    return 1;
+}
+
 1;
