@@ -1,10 +1,12 @@
 #ifndef _MESSAGE_H
 #define _MESSAGE_H
 
+#define MSG_MIME_HEADER  "Content-type: "
+
 #if defined(_WIN32) || defined(__EMX__)
-#define MSG_MIME_HEADER  "Content-type: text/html\n\n"
+#define CRLF "\n"
 #else
-#define MSG_MIME_HEADER  "Content-type: text/html\r\n\r\n"
+#define CRLF "\r\n"
 #endif
 
 #endif /* _MESSAGE_H */
